# Ω*
#               ■          ■■■■■  
#               ■         ■■   ■■ 
#               ■        ■■     ■ 
#               ■        ■■       
#     ■■■■■     ■        ■■■      
#    ■■   ■■    ■         ■■■     
#   ■■     ■■   ■          ■■■■   
#   ■■     ■■   ■            ■■■■ 
#   ■■■■■■■■■   ■              ■■■
#   ■■          ■               ■■
#   ■■          ■               ■■
#   ■■     ■    ■        ■■     ■■
#    ■■   ■■    ■   ■■■  ■■■   ■■ 
#     ■■■■■     ■   ■■■    ■■■■■


"""
Moca System Core Module
モカシステムコアモジュール
茉客系统核心模块

[MocaCore]

Copyright (c) 2020.1.17 [el.ideal-ideas]

This software is released under the MIT License. see LICENSE.txt.

https://www.el-ideal-ideas.com
"""


# -- Imports --------------------------------------------------------------------------

from typing import List
from enum import Enum
from sys import platform

# -------------------------------------------------------------------------- Imports --

# -- Constants --------------------------------------------------------------------------

VERSION = '1.0.2'

# Logo
EL_S: str = """
----------------------------------------------------------------------------
----------------------------------------------------------------------------
Ω*
              ■          ■■■■■  
              ■         ■■   ■■ 
              ■        ■■     ■ 
              ■        ■■       
    ■■■■■     ■        ■■■      
   ■■   ■■    ■         ■■■     
  ■■     ■■   ■          ■■■■   
  ■■     ■■   ■            ■■■■ 
  ■■■■■■■■■   ■              ■■■
  ■■          ■               ■■
  ■■          ■               ■■
  ■■     ■    ■        ■■     ■■
   ■■   ■■    ■   ■■■  ■■■   ■■ 
    ■■■■■     ■   ■■■    ■■■■■

----------------------------------------------------------------------------
----------------------------------------------------------------------------
"""

# japanese Hiragana list
# あ -- ん [:46]
# ぁ -- っ [46:55]
# が -- ぽ [55:]
HIRAGANA: List[str] = ["あ", "い", "う", "え", "お",
                       "か", "き", "く", "け", "こ",
                       "さ", "し", "す", "せ", "そ",
                       "た", "ち", "つ", "て", "と",
                       "な", "に", "ぬ", "ね", "の",
                       "は", "ひ", "ふ", "へ", "ほ",
                       "ま", "み", "む", "め", "も",
                       "や", "ゆ", "よ",
                       "ら", "り", "る", "れ", "ろ",
                       "わ", "を",
                       "ん",
                       "ぁ", "ぃ", "ぅ", "ぇ", "ぉ",
                       "ゃ", "ゅ", "ょ",
                       "っ",
                       "が", "ぎ", "ぐ", "げ", "ご",
                       "ざ", "じ", "ず", "ぜ", "ぞ",
                       "だ", "ぢ", "づ", "で", "ど",
                       "ば", "び", "ぶ", "べ", "ぼ",
                       "ぱ", "ぴ", "ぷ", "ぺ", "ぽ"]

# japanese Katakana list
# ア -- ン [:46]
# ァ -- ッ [46:55]
# ガ -- ポ [55:]
KATAKANA: List[str] = ["ア", "イ", "ウ", "エ", "オ",
                       "カ", "キ", "ク", "ケ", "コ",
                       "サ", "シ", "ス", "セ", "ソ",
                       "タ", "チ", "ツ", "テ", "ト",
                       "ナ", "ニ", "ヌ", "ネ", "ノ",
                       "ハ", "ヒ", "フ", "ヘ", "ホ",
                       "マ", "ミ", "ム", "メ", "モ",
                       "ヤ", "ユ", "ヨ",
                       "ラ", "リ", "ル", "レ", "ロ",
                       "ワ", "ヲ",
                       "ン",
                       "ァ", "ィ", "ゥ", "ェ", "ォ",
                       "ャ", "ュ", "ョ",
                       "ッ",
                       "ガ", "ギ", "グ", "ゲ", "ゴ",
                       "ザ", "ジ", "ズ", "ゼ", "ゾ",
                       "ダ", "ヂ", "ヅ", "デ", "ド",
                       "バ", "ビ", "ブ", "ベ", "ボ",
                       "パ", "ピ", "プ", "ペ", "ポ"]

# alphabet uppercase letter
ALPHABET_UPPERCASE = ['A', 'B', 'C', 'D', 'E', 'F', 'G',
                      'H', 'I', 'J', 'K', 'L', 'M', 'N',
                      'O', 'P', 'Q', 'R', 'S', 'T', 'U',
                      'V', 'W', 'X', 'Y', 'Z']

# alphabet lowercase letter
ALPHABET_LOWERCASE = ['a', 'b', 'c', 'd', 'e', 'f', 'g',
                      'h', 'i', 'j', 'k', 'l', 'm', 'n',
                      'o', 'p', 'q', 'r', 's', 't', 'u',
                      'v', 'w', 'x', 'y', 'z']

# number list
DIGITS = ['0', '1', '2', '3', '4', '5', '6', '7', '8', '9']

# don't worry about it.
# a kind of wordplay
# もちは至高
MOCHI_MOCHI = 'もっちもっちにゃんにゃん！'
# めんだこ帝国万歳
MENDAKO = 'いあ！いあ！めんだこちゃん！ふたぐん！'


class ConsoleColor(str, Enum):
    """
    Color data type
    """
    BLACK: str = '\033[30m'
    RED: str = '\033[31m'
    GREEN: str = '\033[32m'
    YELLOW: str = '\033[33m'
    BLUE: str = '\033[34m'
    PURPLE: str = '\033[35m'
    CYAN: str = '\033[36m'
    WHITE: str = '\033[37m'
    END: str = '\033[0m'
    BOLD: str = '\038[1m'
    UNDERLINE: str = '\033[4m'
    INVISIBLE: str = '\033[08m'
    REVERCE: str = '\033[07m'


N: str = '\n'

# -------------------------------------------------------------------------- Constants --

# -- Setup --------------------------------------------------------------------------

if platform == 'win32' or platform == 'cygwin':
    N = '\r\n'

# -------------------------------------------------------------------------- Setup --
